<?php

/**
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many individuals
 * and is licensed under the LGPL. For more information please see
 * <http://phing.info>.
 */

declare(strict_types=1);

namespace Phing\Test\Task\Ext\Sass;

use Phing\Task\Ext\Sass\SassTask;
use PHPUnit\Framework\TestCase;

/**
 * @internal
 */
class SassTaskUnitTest extends TestCase
{
    /** @var SassTask */
    private $object;

    /** @var SassTaskAssert */
    private $sassTaskAssert;

    public function setUp(): void
    {
        $this->object = new SassTask();
        $this->sassTaskAssert = new SassTaskAssert();
    }

    public function testCheckDefaults(): void
    {
        $this->sassTaskAssert->assertDefaults($this->object);
    }

    public function testSetStyleCompactViaSetStyle(): void
    {
        $this->object->setStyle('crunched');
        $this->object->setStyle('compact');
        $this->sassTaskAssert->assertCompactStyle($this->object);
    }

    public function testSetStyleCompactViaOwnMethod(): void
    {
        $this->object->setStyle('crunched');
        $this->object->setCompact('yes');
        $this->sassTaskAssert->assertCompactStyle($this->object);
    }

    public function testSetStyleCompressedViaSetStyle(): void
    {
        $this->object->setStyle('crunched');
        $this->object->setStyle('compressed');
        $this->sassTaskAssert->assertCompressedStyle($this->object);
    }

    public function testSetStyleCompressedViaOwnMethod(): void
    {
        $this->object->setStyle('crunched');
        $this->object->setCompressed('yes');
        $this->sassTaskAssert->assertCompressedStyle($this->object);
    }
}
